cursorPosition property

NodeCoordinate? cursorPosition
final

The cursor position at the moment of the click event, if available.

This value is only populated via NodeInfo.fromJson when receiving a click event from the JavaScript bridge. It is null when NodeInfo is constructed manually.

Implementation

final NodeCoordinate? cursorPosition;